import os

NAME = "bluer_options"

ICON = "🌀"

DESCRIPTION = f"{ICON} options for Bash."

VERSION = "5.4.1"

REPO_NAME = "bluer-options"

MARQUEE = "https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
